##Photo Galleries

####Adding a gallery

1. The "Header" block defines your headlines.   
    - "Kicker/Overline": an optional field to add a kicker or overline, if desired.  
    - "Title/Headline": the story headline. All stories must have a headline.  
2. The "Content" block defines the main story content.  
    - "Summary Description": A strong, catchy teaser/summary should be used. It will be seen on the articles list page, on the home page, anywhere the story is syndicated, and possibly in search engine results. The importance of the teaser can not be overstated. It is how people will decide whether or not they want to read the full story.  
    - "Article": Optionally associate this photo gallery with a story.  
    - "Bulk upload": Optionally upload multiple images at once to this gallery 
3. "Meta" allows giving a credit (byline) to the gallery, and marking it as published or not.
4. "Admin fields" is collapsed by default, and you should rarely need to touch them. If you do...
	- Slug is the story slug and is used for URLs. It should auto-populate based on the headline. If you change it, you will break existing URLs.
5. Gallery Images are allow you to attach photos one-at-a-time directly to a gallery. 
    - If the bulk upload option is used, it will populate these fields.
    - You can also edit the caption and byline associated with photos.
    - They can be reordered by dragging and dropping them in the order you would like, or by entering digits in the "Order" field.
